==> gatling-http-client-3.6.0-sources.jar: io/gatling/http/client/body/multipart/FileLikePart.java <==
/*
 * Copyright 2011-2021 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.http.client.body.multipart;

import io.gatling.http.client.Param;
import io.gatling.http.client.util.MimeTypes;
import io.gatling.http.client.util.MiscUtils;

import java.nio.charset.Charset;
import java.util.List;

public abstract class FileLikePart<T> extends Part<T> {

  private final String fileName;

  FileLikePart(String name, T content, Charset charset, String transferEncoding, String contentId, String dispositionType, String contentType, List<Param> customHeaders, String fileName) {
    super(name,
            content,
            charset,
            transferEncoding,
            contentId,
            dispositionType,
            computeContentType(contentType, fileName),
            customHeaders
            );
    this.fileName = fileName;
  }

  private static String computeContentType(String contentType, String fileName) {
    return contentType != null ? contentType : MimeTypes.getMimeType(MiscUtils.withDefault(fileName, ""));
  }

  public String getFileName() {
    return fileName;
  }
}

==> gatling-http-client-3.7.2-sources.jar: io/gatling/http/client/body/multipart/FileLikePart.java <==
/*
 * Copyright 2011-2021 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.http.client.body.multipart;

import io.gatling.http.client.Param;
import io.gatling.http.client.util.MimeTypes;
import io.gatling.http.client.util.MiscUtils;
import java.nio.charset.Charset;
import java.util.List;

public abstract class FileLikePart<T> extends Part<T> {

  private final String fileName;

  FileLikePart(
      String name,
      T content,
      Charset charset,
      String transferEncoding,
      String contentId,
      String dispositionType,
      String contentType,
      List<Param> customHeaders,
      String fileName) {
    super(
        name,
        content,
        charset,
        transferEncoding,
        contentId,
        dispositionType,
        computeContentType(contentType, fileName),
        customHeaders);
    this.fileName = fileName;
  }

  private static String computeContentType(String contentType, String fileName) {
    return contentType != null
        ? contentType
        : MimeTypes.getMimeType(MiscUtils.withDefault(fileName, ""));
  }

  public String getFileName() {
    return fileName;
  }
}
